@@ -142,7 +142,8 @@ def wait_ctrl_c(pre_msg="Press Ctrl+c to quit Tensorboard", post_msg="\nExit."):
 def get_tf_callbacks(root,
                      tboard_callback=True, tboard_update_freq='epoch', tboard_histogram_freq=1, tboard_profile_batch=0,
                      confuse_callback=True, label_info=None, x_test=None, y_test=None, test_generator_=None, figure_size=(12, 10),
-                     modelsaver_callback=False, best_loss=float('inf'), save_root=None, best_epoch=0):
+                     modelsaver_callback=False, best_loss=float('inf'), save_root=None, best_epoch=0,
+                     earlystop_callback=True, earlystop_monitor='val_loss', earlystop_patience=0, earlystop_restore_weights=True):
     postfix = datetime.datetime.now().strftime("%Y%m%d-%H%M%S")
     log_root_ = "{}{}/".format(root, postfix)
 
@@ -174,4 +175,8 @@ def get_tf_callbacks(root,
             ModelSaverCallback(best_loss=best_loss, save_root=save_root, epoch=best_epoch)
         )
 
+    if earlystop_callback:
+        callbacks_.append(tf.keras.callbacks.EarlyStopping(monitor=earlystop_monitor, patience=earlystop_patience,
+                                                           restore_best_weights=earlystop_restore_weights))
+
     return callbacks_, log_root_
